@@ -1,8 +1,8 @@
 .First.lib <- function(lib,pkg)
 {
   library.dynam("sdcMicro",pkg,lib)
-  cat("\n sdcMicro version 2.5.0 has been loaded \n\n")
-
+  cat("\n--------\n\n")
+  cat("\n", citation("sdcMicro")$note, "loaded.\n\n" )
   cat("--------\n\n")
 }
 
